/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include	"xlerror.h"
#include	"xl.h"


int exit_mode;

XL_SEXP * genExit();


int genExit_no;
int genExit_tid;

void
init_genExit(XLISP_ENV * env)
{
	set_env(env,l_string(std_cm,"Exit"),
		get_func_prim(genExit,FO_APPLICATIVE,0,1,1));
}

XL_SEXP *
genExit(XLISP_ENV * env,XL_SEXP * s)
{
//int iid;
XL_SEXP * ret;

genExit_no = 1;
genExit_tid = get_tid();
/*
  	iid = get_main_interpreter();
genExit_no = 2;
genExit_tid = get_tid();
	if ( iid >= 0 )
		close_interpreter(iid);
genExit_no = 3;
genExit_tid = get_tid();
*/
	ret = get_error(
		s->h.file,
		s->h.line,
		XLE_SYSTEM_EXIT,
		l_string(std_cm,"Exit"),
		0);
genExit_no = 4;
genExit_tid = get_tid();
	return ret;
}


